@@ -2,9 +2,11 @@
 Web application user interface.
 Encapsulates tests from interacting directly with Selenium.
 """
+import os
 import socket
 from collections import Mapping
 import splinter
+from .promise import EmptyPromise, fulfill
 
 import logging
 LOGGER = logging.getLogger(__name__)
@@ -156,6 +158,23 @@ class WebAppUI(Mapping):
         # Ask the page object to verify that the correct page loaded
         self._verify_page(page)
 
+    def wait_for_page(self, page_name, timeout=30):
+        """
+        Block until the page named `page_name` loads.
+
+        Useful for ensuring that we navigate successfully from the current
+        page to the next page.
+
+        Raises a `WebAppUIConfigError` if the page object doesn't exist.
+        Raises a `BrokenPromise` exception if the page fails to load within `timeout` seconds.
+        """
+        next_page = self._get_page_or_error(page_name)
+        return fulfill(
+            EmptyPromise(
+                next_page.is_browser_on_page,
+                "loaded page '{0}'".format(page_name)
+        ))
+
     def __getitem__(self, key):
         """
         Return the page object with the name `key`.
@@ -215,6 +234,22 @@ class WebAppUI(Mapping):
         """
         self._browser.quit()
 
+    def save_screenshot(self, name):
+        """
+        Save a screenshot of the browser.
+
+        The location of the screenshot can be configured
+        by the environment variable `SCREENSHOT_DIR`.  If not set,
+        this defaults to the current working directory.
+
+        `name` is a name for the screenshot, which will be used
+        in the output file name.
+        """
+        image_name = os.path.join(
+            os.environ.get('SCREENSHOT_DIR', ''), name + '.png'
+        )
+        self._browser.driver.save_screenshot(image_name)
+
     def _get_page_or_error(self, page_name):
         """
         Retrieve the page object, or raise
